@@ -17,7 +17,7 @@ pub use api::server::run_daemon;
 
 use clap::Parser;
 use driver::{btrfs, external, zfs};
-use ruc::*;
+use ruc::{cmd, *};
 use std::{fmt, result::Result as StdResult, str::FromStr};
 
 /// Maximum number of snapshots that can be kept
@@ -124,17 +124,43 @@ impl BtmCfg {
     /// try to guess a correct mode
     /// NOTE: not suitable for `External` mode
     #[inline(always)]
-    pub fn guess_mode(&self) -> Result<SnapMode> {
-        zfs::check(&self.volume)
+    pub fn guess_mode(volume: &str) -> Result<SnapMode> {
+        zfs::check(volume)
             .c(d!())
             .map(|_| SnapMode::Zfs)
-            .or_else(|e| btrfs::check(&self.volume).c(d!(e)).map(|_| SnapMode::Btrfs))
+            .or_else(|e| btrfs::check(volume).c(d!(e)).map(|_| SnapMode::Btrfs))
     }
 
     #[inline(always)]
     fn get_cap(&self) -> u64 {
         alt!(self.cap > CAP_MAX, CAP_MAX, self.cap)
     }
+
+    /// List all existing snapshots.
+    pub fn list_snapshots(&self) -> Result<()> {
+        println!("Available snapshots are listed below:");
+        self.get_sorted_snapshots().c(d!()).map(|list| {
+            list.into_iter().rev().for_each(|h| {
+                println!("    {}", h);
+            })
+        })
+    }
+
+    /// Clean all existing snapshots.
+    pub fn clean_snapshots(&self) -> Result<()> {
+        self.get_sorted_snapshots().c(d!()).map(|list| {
+            list.into_iter().rev().for_each(|height| {
+                let cmd = match self.mode {
+                    SnapMode::Btrfs => {
+                        format!("btrfs subvolume delete {}@{}", &self.volume, height)
+                    }
+                    SnapMode::Zfs => format!("zfs destroy {}@{}", &self.volume, height),
+                    _ => pnk!(Err(eg!("Unsupported deriver"))),
+                };
+                info_omit!(cmd::exec_output(&cmd));
+            });
+        })
+    }
 }
 
 /// # Inner Operations
